@@ -107,15 +107,20 @@ class WH:
         device-specific electricity consumption while satisfying comfort bounds, second attempt 
         minimizes the deviation of the new temperature and the desired setpoint.
         """
+        print('resolving try 1')
         cons = self.add_constraints()
         obj = cp.Minimize(cp.sum(self.p * self.heat_on))
         prob = cp.Problem(obj, cons)
         prob.solve(solver=cp.GLPK_MI)
+
         if not prob.status == 'optimal':
+            print('resolving try 2')
             cons = self.add_constraints(enforce_bounds=False)
-            obj = cp.Minimize(cp.sum(self.temp_wh_ev - self.temp_wh_max))
+            obj = cp.Minimize(cp.sum(self.temp_wh_max - self.temp_wh_ev))
             prob = cp.Problem(obj, cons)
-            prob.solve(solver=self.hems.solver)
+            prob.solve(solver=self.hems.solver, verbose=True)
+            if not prob.status == 'optimal':
+                print('still not fixed')
 
     def override_p_wh(self, cmd):
         """
